| Title: | Genetic Association Analysis |
|---|---|
| Description: | This is a companion to Henry-Stewart talk by Zhao (2026, <doi:10.69645/FRFQ9519>), which gathers information, metadata and scripts to showcase modern genetic analysis -- ranging from testing of polymorphic variant(s) for Hardy-Weinberg equilibrium, association with traits using genetic and statistical models, Bayesian implementation, power calculation in study design, and genetic annotation. It also covers R integration with the Linux environment, GitHub, package creation and web applications. The earlier version by Zhao (2009, <doi:10.69645/DCRY5578>) provides a brief introduction to these topics. |
| Authors: | Jing Hua Zhao [aut, cre] (ORCID: <https://orcid.org/0000-0002-1463-5870>, ORCID: <https://orcid.org/0000-0003-4930-3582>), Benjamin Altmann [ctb], Brian Ripley [ctb] |
| Maintainer: | Jing Hua Zhao <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.7 |
| Built: | 2026-05-28 18:37:22 UTC |
| Source: | https://github.com/jinghuazhao/gaawr2 |
It prints a welcome message, saying number of times.
welcome(n)welcome(n)
n |
The number of times (>1 integer) to welcome the user. |
Prints a welcome message to the console.
welcome(3)welcome(3)